pub struct JsonDataBigInt {
pub value: u64,
}Expand description
Represents a large integer value for document data, particularly useful for interacting with
languages or environments that support large numeric types, such as the bigint in JavaScript.
Fields
value: Au64integer representing the large numeric value encapsulated by this struct.
Fields
value: u64Trait Implementations
Sourceimpl Clone for JsonDataBigInt
impl Clone for JsonDataBigInt
Sourcefn clone(&self) -> JsonDataBigInt
fn clone(&self) -> JsonDataBigInt
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for JsonDataBigInt
impl Debug for JsonDataBigInt
Sourceimpl<'de> Deserialize<'de> for JsonDataBigInt
impl<'de> Deserialize<'de> for JsonDataBigInt
Sourcefn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for JsonDataBigInt
impl Display for JsonDataBigInt
Sourceimpl Hash for JsonDataBigInt
impl Hash for JsonDataBigInt
Sourceimpl Ord for JsonDataBigInt
impl Ord for JsonDataBigInt
Sourcefn cmp(&self, other: &JsonDataBigInt) -> Ordering
fn cmp(&self, other: &JsonDataBigInt) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for JsonDataBigInt
impl PartialEq for JsonDataBigInt
Sourceimpl PartialOrd for JsonDataBigInt
impl PartialOrd for JsonDataBigInt
Sourceimpl Serialize for JsonDataBigInt
impl Serialize for JsonDataBigInt
impl Copy for JsonDataBigInt
impl Eq for JsonDataBigInt
impl StructuralPartialEq for JsonDataBigInt