pub struct JsonDataPrincipal {
pub value: Principal,
}Expand description
Represents a wrapper around the candid::Principal type.
This struct is designed to encapsulate a Candid Principal, allowing for integration and usage within Juno hooks contexts.
Fields
value: ThePrincipalthis struct wraps.
Fields
value: PrincipalTrait Implementations
Sourceimpl Clone for JsonDataPrincipal
impl Clone for JsonDataPrincipal
Sourcefn clone(&self) -> JsonDataPrincipal
fn clone(&self) -> JsonDataPrincipal
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for JsonDataPrincipal
impl Debug for JsonDataPrincipal
Sourceimpl<'de> Deserialize<'de> for JsonDataPrincipal
impl<'de> Deserialize<'de> for JsonDataPrincipal
Sourcefn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for JsonDataPrincipal
impl Hash for JsonDataPrincipal
Sourceimpl Ord for JsonDataPrincipal
impl Ord for JsonDataPrincipal
Sourcefn cmp(&self, other: &JsonDataPrincipal) -> Ordering
fn cmp(&self, other: &JsonDataPrincipal) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for JsonDataPrincipal
impl PartialEq for JsonDataPrincipal
Sourceimpl PartialOrd for JsonDataPrincipal
impl PartialOrd for JsonDataPrincipal
Sourceimpl Serialize for JsonDataPrincipal
impl Serialize for JsonDataPrincipal
impl Copy for JsonDataPrincipal
impl Eq for JsonDataPrincipal
impl StructuralPartialEq for JsonDataPrincipal